%define anolis_release 3

Name:      hunspell
Summary:   A spell checker and morphological analyzer library
Version:   1.7.1
Release:   %{anolis_release}%{?dist}
Source:    https://github.com/hunspell/hunspell/releases/download/v%{version}/hunspell-%{version}.tar.gz
URL:       https://github.com/hunspell/hunspell
License:   LGPLv2+ or GPLv2+ or MPLv1.1
BuildRequires:  gcc-c++
BuildRequires: autoconf, automake, libtool, ncurses-devel, gettext-devel
BuildRequires: perl-generators
%ifarch x86_64
BuildRequires: valgrind
%endif
BuildRequires: words
BuildRequires: make
Requires:  hunspell-en-US
Requires:  hunspell-filesystem = %{version}-%{release}

%description
Hunspell is a spell checker and morphological analyzer library and program
designed for languages with rich morphology and complex word compounding or
character encoding. Hunspell interfaces: Ispell-like terminal interface using
Curses library, Ispell pipe interface, LibreOffice UNO module.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%package devel
Requires: hunspell = %{version}-%{release}, pkgconfig
Summary: Files for developing with hunspell

%description devel
Includes and definitions for developing with hunspell

%package filesystem
Summary: Hunspell filesystem layout

%description filesystem
Provides a directory in which to store dictionaries provided by other
packages.

%prep
%setup -q

%build
autoreconf -vfi
configureflags="--disable-rpath --disable-static --with-ui --with-readline"

%define profilegenerate \
    CFLAGS="${RPM_OPT_FLAGS} -fprofile-generate"\
    CXXFLAGS="${RPM_OPT_FLAGS} -fprofile-generate"
%define profileuse \
    CFLAGS="${RPM_OPT_FLAGS} -fprofile-use"\
    CXXFLAGS="${RPM_OPT_FLAGS} -fprofile-use"

#Generate a word list to use for profiling, take half of it to ensure
#that the original word list is then considered to contain correctly
#and incorrectly spelled words
head -n $((`cat /usr/share/dict/words | wc -l`/2)) /usr/share/dict/words |\
    sed '/\//d'> words

#generate profiling
%{profilegenerate} %configure $configureflags
%make_build
./src/tools/affixcompress words > /dev/null 2>&1
./src/tools/hunspell -d words -l /usr/share/dict/words > /dev/null
make check
make distclean

#use profiling
%{profileuse} %configure $configureflags
%make_build
cd po && %make_build update-gmo && cd ..

%check
%ifarch %{ix86} x86_64
VALGRIND=memcheck make check
make check
%endif

%install
rm -rf $RPM_BUILD_ROOT
%make_install
rm -f $RPM_BUILD_ROOT/%{_libdir}/*.a
rm -f $RPM_BUILD_ROOT/%{_libdir}/*.la
mkdir $RPM_BUILD_ROOT/%{_datadir}/hunspell
mkdir $RPM_BUILD_ROOT/%{_datadir}/myspell
%find_lang %{name}

%generate_compatibility_deps

%ldconfig_scriptlets

%files -f %{name}.lang
%doc COPYING COPYING.LESSER COPYING.MPL license.hunspell license.myspell
%{_libdir}/*.so.*
%{_bindir}/hunspell
%{abidir}/*.dump
%{abidir}/hunspell-option.list
%{_mandir}/man1/hunspell.1.zst
%{_mandir}/hu/man1/hunspell.1.zst

%files doc
%doc README AUTHORS THANKS

%files devel
%{_includedir}/%{name}
%{_libdir}/*.so
%{_bindir}/affixcompress
%{_bindir}/makealias
%{_bindir}/munch
%{_bindir}/unmunch
%{_bindir}/analyze
%{_bindir}/chmorph
%{_bindir}/hzip
%{_bindir}/hunzip
%{_bindir}/ispellaff2myspell
%{_bindir}/wordlist2hunspell
%{_bindir}/wordforms
%{abidir}/affixcompress-option.list
%{abidir}/makealias-option.list
%{abidir}/hunzip-option.list
%{_libdir}/pkgconfig/hunspell.pc
%{abidir}/ispellaff2myspell-option.list
%{_mandir}/man1/hunzip.1.zst
%{_mandir}/man1/hzip.1.zst
%{_mandir}/man3/hunspell.3.zst
%{_mandir}/man5/hunspell.5.zst

%files filesystem
%dir %{abidir}
%{_datadir}/hunspell
%{_datadir}/myspell

%changelog
* Thu Nov 16 2023 Wenlong Zhang<zhangwenlong@loongson.cn> - 1.7.1-3
- fix build error for hunspell

* Wed Oct 26 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.7.1-2
- optimise spec file

* Tue Sep 20 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.7.1-1
update to 1.7.1

* Tue Apr 12 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1.7.0-1
- init from upstream
